.. yatr documentation master file, created by
   sphinx-quickstart on Fri Oct  6 23:35:35 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../README.rst

Contents:
=========
.. toctree::
   :maxdepth: 2

   install
   yatrfile
   cli
   future
   yatr
   changelog

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

